@@ -82,6 +82,16 @@ while True:
         )
         print("Latitude: {0:.6f} degrees".format(gps.latitude))
         print("Longitude: {0:.6f} degrees".format(gps.longitude))
+        print(
+            "Precise Latitude: {:2.}{:2.4f} degrees".format(
+                gps.latitude_degrees, gps.latitude_minutes
+            )
+        )
+        print(
+            "Precise Longitude: {:2.}{:2.4f} degrees".format(
+                gps.longitude_degrees, gps.longitude_minutes
+            )
+        )
         print("Fix quality: {}".format(gps.fix_quality))
         # Some attributes beyond latitude, longitude and timestamp are optional
         # and might not be present.  Check if they're None before trying to use!
@@ -96,4 +106,4 @@ while True:
         if gps.horizontal_dilution is not None:
             print("Horizontal dilution: {}".format(gps.horizontal_dilution))
         if gps.height_geoid is not None:
-            print("Height geo ID: {} meters".format(gps.height_geoid))
+            print("Height geoid: {} meters".format(gps.height_geoid))
